@@ -437,25 +437,23 @@ class InfEngineServer:
         if count:
             self._logger.info(f"Deleted {count} releases.")
 
-    def _clean(self, dir: Path, ignore: Path, limit: int = 0) -> int:
+    def _clean(self, directory: Path, ignore: Path, limit: int = 0) -> int:
         """ Delete several directories from the passed directory. """
 
         counter = 0
 
-        if dir.is_dir():
-            for obj in dir.iterdir():
-                if obj != ignore:
-                    if obj.is_dir():
-                        self._logger.info(obj)
-
-                if counter == 0:
+        if directory.is_dir():
+            for obj in directory.iterdir():
+                if limit - counter <= 0:
                     break
 
-        return counter
+                if obj != ignore:
+                    if obj.is_dir():
+                        self._logger.debug(obj)
 
-    def _clean_multidb(self):
-        # TODO
-        pass
+                        counter += 1
+
+        return counter
 
     def update_data(
         self,
@@ -508,6 +506,7 @@ class InfEngineServer:
 
         engine.install(dldata, dlsources, db_name=db_name)
 
+        engine.clean()
         self.clean()
         self.restart()
 
