@@ -346,7 +346,7 @@ class InfEngineServerEngine:
                     break
 
                 if obj.is_dir():
-                    self._logger.debug(obj)
+                    self._logger.info(obj)
 
                     counter += 1
 
