@@ -18,7 +18,7 @@ def create_temp_dir(parent_dir: Path) -> Path:  # tempfile.TemporaryDirectory:
 
     randomized_name = "".join(random.choices(string.ascii_letters, k=6))
     temp_dir = (
-        parent_dir / f"{datetime.datetime.now().strftime('%Y-%m-%d_%H-%M')}"
+        parent_dir / f"{datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}"
         f"_{randomized_name}"
     )
     temp_dir.mkdir(parents=True)
